@@ -1,5 +1,5 @@
 Clazz.declarePackage ("JV");
-Clazz.load (["java.util.Hashtable"], "JV.StatusManager", ["java.lang.Boolean", "$.Float", "JU.Lst", "$.PT", "J.api.Interface", "J.c.CBK", "JS.SV", "JU.Logger"], function () {
+Clazz.load (["java.util.Hashtable"], "JV.StatusManager", ["java.lang.Boolean", "$.Float", "JU.Lst", "$.PT", "J.api.Interface", "J.c.CBK", "JS.SV", "JU.Logger", "JV.JC"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.vwr = null;
 this.jsl = null;
@@ -72,19 +72,34 @@ return list;
 }, "~S");
 Clazz.defineMethod (c$, "jmolScriptCallback", 
  function (callback) {
-var s = this.jmolScriptCallbacks.get (callback);
+var s = this.jmolScriptCallbacks.get (callback.name ());
 if (s != null) this.vwr.evalStringQuietSync (s, true, false);
+if (this.jmolScriptCallbacks.containsKey ("SYNC:" + callback.name ())) s = "SYNC";
 return s;
 }, "J.c.CBK");
 Clazz.defineMethod (c$, "setCallbackFunction", 
 function (callbackType, callbackFunction) {
-var callback = J.c.CBK.getCallback (callbackType);
-System.out.println ("StatusManager callback set for " + callbackType + " f=" + callbackFunction + " cb=" + callback);
-if (callback != null) {
-var pt = (callbackFunction == null ? 0 : callbackFunction.length > 7 && callbackFunction.toLowerCase ().indexOf ("script:") == 0 ? 7 : callbackFunction.length > 11 && callbackFunction.toLowerCase ().indexOf ("jmolscript:") == 0 ? 11 : 0);
-if (pt == 0) this.jmolScriptCallbacks.remove (callback);
- else this.jmolScriptCallbacks.put (callback, callbackFunction.substring (pt).trim ());
-}if (this.cbl != null) this.cbl.setCallbackFunction (callbackType, callbackFunction);
+var cbk = J.c.CBK.getCallback (callbackType);
+if (cbk != null) {
+var callback = J.c.CBK.getCallback (callbackType).name ();
+JU.Logger.info ("StatusManager callback set for " + callbackType + " f=" + callbackFunction + " cb=" + callback);
+var isSync = (callbackFunction != null && callbackFunction.startsWith ("SYNC:"));
+if (isSync) {
+if (callbackFunction.toLowerCase ().trim ().equals ("sync:off")) {
+this.jmolScriptCallbacks.remove ("SYNC:" + callback);
+JU.Logger.info ("SYNC callback for " + callback + " deactivated");
+} else {
+this.jmolScriptCallbacks.put ("SYNC:" + callback, "_");
+JU.Logger.info ("SYNC callback for " + callback + " activated");
+return;
+}} else {
+var lc = "";
+var pt = (callbackFunction == null ? 0 : (lc = callbackFunction.toLowerCase ()).startsWith ("script:") ? 7 : lc.startsWith ("jmolscript:") ? 11 : 0);
+if (pt == 0) {
+this.jmolScriptCallbacks.remove (callback);
+} else {
+this.jmolScriptCallbacks.put (callback, callbackFunction.substring (pt).trim ());
+}}}if (this.cbl != null) this.cbl.setCallbackFunction (callbackType, callbackFunction);
 }, "~S,~S");
 Clazz.defineMethod (c$, "notifyEnabled", 
 function (type) {
@@ -436,6 +451,119 @@ if (status === "ended") this.registerAudio (htParams.get ("id"), null);
 var sJmol = this.jmolScriptCallback (J.c.CBK.AUDIO);
 if (this.notifyEnabled (J.c.CBK.AUDIO)) this.cbl.notifyCallback (J.c.CBK.AUDIO,  Clazz.newArray (-1, [sJmol, htParams]));
 }, "java.util.Map");
+Clazz.defineMethod (c$, "syncScript", 
+function (script, applet, port) {
+if ("GET_GRAPHICS".equalsIgnoreCase (script)) {
+this.setSyncDriver (5);
+this.syncSend (script, applet, 0);
+this.vwr.setBooleanProperty ("_syncMouse", false);
+this.vwr.setBooleanProperty ("_syncScript", false);
+return;
+}if ("=".equals (applet)) {
+applet = "~";
+this.setSyncDriver (2);
+}var disableSend = "~".equals (applet);
+if (port > 0 || !disableSend && !".".equals (applet)) {
+this.syncSend (script, applet, port);
+if (!"*".equals (applet) || script.startsWith ("{")) return;
+}if (script.equalsIgnoreCase ("on") || script.equalsIgnoreCase ("true")) {
+this.setSyncDriver (1);
+return;
+}if (script.equalsIgnoreCase ("off") || script.equalsIgnoreCase ("false")) {
+this.setSyncDriver (0);
+return;
+}if (script.equalsIgnoreCase ("slave")) {
+this.setSyncDriver (2);
+return;
+}var syncMode = this.getSyncMode ();
+if (syncMode == 0) return;
+if (syncMode != 1) disableSend = false;
+if (JU.Logger.debugging) JU.Logger.debug (this.vwr.htmlName + " syncing with script: " + script);
+if (disableSend) this.setSyncDriver (3);
+if (script.indexOf ("Mouse: ") != 0) {
+var serviceMode = JV.JC.getServiceCommand (script);
+switch (serviceMode) {
+case 70:
+case 42:
+case 49:
+case 56:
+case 63:
+this.syncSend (script, ".", port);
+return;
+case -1:
+break;
+case 0:
+case 77:
+case 28:
+case 35:
+if (disableSend) return;
+case 21:
+case 7:
+case 14:
+if ((script = this.vwr.getJSV ().processSync (script, serviceMode)) == null) return;
+}
+this.vwr.evalStringQuietSync (script, true, false);
+return;
+}this.mouseScript (script);
+if (disableSend) this.vwr.setSyncDriver (4);
+}, "~S,~S,~N");
+Clazz.defineMethod (c$, "mouseScript", 
+function (script) {
+var tokens = JU.PT.getTokens (script);
+var key = tokens[1];
+try {
+key = (key.toLowerCase () + "...............").substring (0, 15);
+switch (("zoombyfactor...zoomby.........rotatezby......rotatexyby.....translatexyby..rotatemolecule.spinxyby.......rotatearcball..").indexOf (key)) {
+case 0:
+switch (tokens.length) {
+case 3:
+this.vwr.zoomByFactor (JU.PT.parseFloat (tokens[2]), 2147483647, 2147483647);
+return;
+case 5:
+this.vwr.zoomByFactor (JU.PT.parseFloat (tokens[2]), JU.PT.parseInt (tokens[3]), JU.PT.parseInt (tokens[4]));
+return;
+}
+break;
+case 15:
+switch (tokens.length) {
+case 3:
+this.vwr.zoomBy (JU.PT.parseInt (tokens[2]));
+return;
+}
+break;
+case 30:
+switch (tokens.length) {
+case 3:
+this.vwr.rotateZBy (JU.PT.parseInt (tokens[2]), 2147483647, 2147483647);
+return;
+case 5:
+this.vwr.rotateZBy (JU.PT.parseInt (tokens[2]), JU.PT.parseInt (tokens[3]), JU.PT.parseInt (tokens[4]));
+}
+break;
+case 45:
+this.vwr.rotateXYBy (JU.PT.parseFloat (tokens[2]), JU.PT.parseFloat (tokens[3]));
+return;
+case 60:
+this.vwr.translateXYBy (JU.PT.parseInt (tokens[2]), JU.PT.parseInt (tokens[3]));
+return;
+case 75:
+this.vwr.rotateSelected (JU.PT.parseFloat (tokens[2]), JU.PT.parseFloat (tokens[3]), null);
+return;
+case 90:
+this.vwr.spinXYBy (JU.PT.parseInt (tokens[2]), JU.PT.parseInt (tokens[3]), JU.PT.parseFloat (tokens[4]));
+return;
+case 105:
+this.vwr.rotateXYBy (JU.PT.parseInt (tokens[2]), JU.PT.parseInt (tokens[3]));
+return;
+}
+} catch (e) {
+if (Clazz.exceptionOf (e, Exception)) {
+} else {
+throw e;
+}
+}
+this.vwr.showString ("error reading SYNC command: " + script, false);
+}, "~S");
 Clazz.defineStatics (c$,
 "MAXIMUM_QUEUE_LENGTH", 16,
 "SYNC_OFF", 0,
