@@ -385,7 +385,7 @@ Clazz_defineStatics (c$,
 "posXY",  Clazz_newIntArray (-1, [-2147483648, 0]));
 });
 Clazz_declarePackage ("JSV.js2d");
-Clazz_load (["JSV.dialog.DialogManager"], "JSV.js2d.JsDialogManager", ["javajs.awt.Dimension", "JU.PT", "JSV.js2d.DialogTableModel", "$.JsDialog", "J.awtjs.swing.JDialog", "$.JEditorPane", "$.JLabel", "$.JScrollPane", "$.JTable"], function () {
+Clazz_load (["JSV.dialog.DialogManager"], "JSV.js2d.JsDialogManager", ["JU.PT", "JSV.js2d.DialogTableModel", "$.JsDialog", "JS.Dimension", "$.JDialog", "$.JEditorPane", "$.JLabel", "$.JScrollPane", "$.JTable"], function () {
 c$ = Clazz_declareType (JSV.js2d, "JsDialogManager", JSV.dialog.DialogManager);
 Clazz_makeConstructor (c$, 
 function () {
@@ -411,22 +411,18 @@ return  Clazz_newIntArray (2, 0);
 }, "~O");
 Clazz_overrideMethod (c$, "getOptionFromDialog", 
 function (frame, items, jsvp, dialogName, labelName) {
-var i = -1;
-var applet = this.vwr.html5Applet;
-{
-i = applet.getOption(items, dialogName, labelName);
-}return i;
+return this.vwr.html5Applet.getOption (items, dialogName, labelName);
 }, "~O,~A,JSV.api.JSVPanel,~S,~S");
 Clazz_overrideMethod (c$, "showProperties", 
 function (frame, spectrum) {
-var dialog =  new J.awtjs.swing.JDialog ();
+var dialog =  new JS.JDialog ();
 dialog.setTitle ("Header Information");
 var rowData = spectrum.getHeaderRowDataAsArray ();
 var columnNames =  Clazz_newArray (-1, ["Label", "Description"]);
 var tableModel =  new JSV.js2d.DialogTableModel (columnNames, rowData, false, true);
-var table =  new J.awtjs.swing.JTable (tableModel);
-table.setPreferredScrollableViewportSize ( new javajs.awt.Dimension (400, 195));
-var scrollPane =  new J.awtjs.swing.JScrollPane (table);
+var table =  new JS.JTable (tableModel);
+table.setPreferredScrollableViewportSize ( new JS.Dimension (400, 195));
+var scrollPane =  new JS.JScrollPane (table);
 dialog.getContentPane ().add (scrollPane);
 dialog.pack ();
 dialog.setVisible (true);
@@ -434,15 +430,15 @@ dialog.toFront ();
 }, "~O,JSV.common.Spectrum");
 Clazz_overrideMethod (c$, "showMessage", 
 function (frame, text, title) {
-var dialog =  new J.awtjs.swing.JDialog ();
+var dialog =  new JS.JDialog ();
 {
 dialog.manager = this;
 }dialog.setTitle (title);
 var pane;
 if (text.indexOf ("</div>") >= 0) {
-pane =  new J.awtjs.swing.JLabel (text);
+pane =  new JS.JLabel (text);
 } else {
-pane =  new J.awtjs.swing.JEditorPane ();
+pane =  new JS.JEditorPane ();
 pane.setText (text);
 }dialog.getContentPane ().add (pane);
 dialog.pack ();
@@ -463,7 +459,7 @@ return;
 }, "~S");
 });
 Clazz_declarePackage ("JSV.dialog");
-Clazz_load (null, "JSV.dialog.DialogManager", ["java.util.Hashtable", "JU.PT", "JSV.common.JSVFileManager"], function () {
+Clazz_load (null, "JSV.dialog.DialogManager", ["java.util.Hashtable", "JU.PT", "JSV.common.JSVFileManager", "$.JSViewer"], function () {
 c$ = Clazz_decorateAsClass (function () {
 this.vwr = null;
 this.htSelectors = null;
@@ -514,7 +510,7 @@ this.showMessage (null, spec.getInlineData (), "Inline data");
 return;
 }try {
 var s = JSV.common.JSVFileManager.getFileAsString (filePath);
-if (this.vwr.isJS) s = JU.PT.rep (s, "<", "&lt;");
+if (JSV.common.JSViewer.isJS) s = JU.PT.rep (s, "<", "&lt;");
 this.showMessage (null, s, JSV.dialog.DialogManager.fixTitle (filePath));
 } catch (ex) {
 if (Clazz_exceptionOf (ex, Exception)) {
@@ -566,7 +562,7 @@ Clazz_defineStatics (c$,
 "QUESTION_MESSAGE", 3);
 });
 Clazz_declarePackage ("JSV.js2d");
-Clazz_load (["J.awtjs.swing.AbstractTableModel"], "JSV.js2d.DialogTableModel", ["javajs.api.GenericColor", "JU.CU"], function () {
+Clazz_load (["JS.AbstractTableModel"], "JSV.js2d.DialogTableModel", ["javajs.api.GenericColor", "JU.CU"], function () {
 c$ = Clazz_decorateAsClass (function () {
 this.columnNames = null;
 this.data = null;
@@ -575,7 +571,7 @@ this.widths = null;
 this.thisCol = 0;
 this.tableCellAlignLeft = false;
 Clazz_instantialize (this, arguments);
-}, JSV.js2d, "DialogTableModel", null, J.awtjs.swing.AbstractTableModel);
+}, JSV.js2d, "DialogTableModel", null, JS.AbstractTableModel);
 Clazz_makeConstructor (c$, 
 function (columnNames, data, asString, tableCellAlignLeft) {
 this.columnNames = columnNames;
@@ -649,7 +645,7 @@ style += ";border:" + (isSelected ? 3 : 1) + "px solid #000";
 }, "~S,~N,~N,~O,~B");
 });
 Clazz_declarePackage ("JSV.js2d");
-Clazz_load (["JSV.api.PlatformDialog", "J.awtjs.swing.JDialog", "$.Insets"], "JSV.js2d.JsDialog", ["java.util.Hashtable", "javajs.awt.Color", "$.Dimension", "JSV.common.Annotation", "JSV.js2d.DialogTableModel", "J.awtjs.swing.FlowLayout", "$.GridBagConstraints", "$.GridBagLayout", "$.JButton", "$.JCheckBox", "$.JComboBox", "$.JLabel", "$.JPanel", "$.JScrollPane", "$.JSplitPane", "$.JTable", "$.JTextField"], function () {
+Clazz_load (["JSV.api.PlatformDialog", "JS.JDialog", "$.Insets"], "JSV.js2d.JsDialog", ["java.util.Hashtable", "JSV.common.Annotation", "JSV.js2d.DialogTableModel", "JS.Color", "$.Dimension", "$.FlowLayout", "$.GridBagConstraints", "$.GridBagLayout", "$.JButton", "$.JCheckBox", "$.JComboBox", "$.JLabel", "$.JPanel", "$.JScrollPane", "$.JSplitPane", "$.JTable", "$.JTextField"], function () {
 c$ = Clazz_decorateAsClass (function () {
 this.optionKey = null;
 this.registryKey = null;
@@ -669,10 +665,10 @@ this.buttonInsets = null;
 this.panelInsets = null;
 this.selectedRow = -1;
 Clazz_instantialize (this, arguments);
-}, JSV.js2d, "JsDialog", J.awtjs.swing.JDialog, JSV.api.PlatformDialog);
+}, JSV.js2d, "JsDialog", JS.JDialog, JSV.api.PlatformDialog);
 Clazz_prepareFields (c$, function () {
-this.buttonInsets =  new J.awtjs.swing.Insets (5, 5, 5, 5);
-this.panelInsets =  new J.awtjs.swing.Insets (0, 0, 2, 2);
+this.buttonInsets =  new JS.Insets (5, 5, 5, 5);
+this.panelInsets =  new JS.Insets (0, 0, 2, 2);
 });
 Clazz_makeConstructor (c$, 
 function (manager, jsvDialog, registryKey) {
@@ -684,7 +680,7 @@ this.optionKey = jsvDialog.optionKey;
 this.type = jsvDialog.getAType ();
 this.options = jsvDialog.options;
 if (this.options == null) this.options =  new java.util.Hashtable ();
-this.getContentPane ().setBackground (javajs.awt.Color.get3 (230, 230, 230));
+this.getContentPane ().setBackground (JS.Color.get3 (230, 230, 230));
 this.toFront ();
 }, "JSV.dialog.DialogManager,JSV.dialog.JSVDialog,~S");
 Clazz_defineMethod (c$, "onFocus", 
@@ -698,12 +694,12 @@ this.toFront ();
 }}, "~B");
 Clazz_overrideMethod (c$, "addButton", 
 function (name, text) {
-var btn =  new J.awtjs.swing.JButton ();
-btn.setPreferredSize ( new javajs.awt.Dimension (120, 25));
+var btn =  new JS.JButton ();
+btn.setPreferredSize ( new JS.Dimension (120, 25));
 btn.setText (text);
 btn.setName (this.registryKey + "/" + name);
 btn.addActionListener (this.manager);
-this.thisPanel.add (btn,  new J.awtjs.swing.GridBagConstraints (0, this.iRow++, 3, 1, 0.0, 0.0, 10, 0, this.buttonInsets, 0, 0));
+this.thisPanel.add (btn,  new JS.GridBagConstraints (0, this.iRow++, 3, 1, 0.0, 0.0, 10, 0, this.buttonInsets, 0, 0));
 return btn;
 }, "~S,~S");
 Clazz_overrideMethod (c$, "addCheckBox", 
@@ -712,28 +708,28 @@ if (name == null) {
 this.iRow = 0;
 this.thisPanel = this.rightPanel;
 return null;
-}var cb =  new J.awtjs.swing.JCheckBox ();
+}var cb =  new JS.JCheckBox ();
 cb.setSelected (isSelected);
 cb.setText (title);
 cb.setName (this.registryKey + "/" + name);
 cb.addActionListener (this.manager);
-var insets =  new J.awtjs.swing.Insets (0, 20 * level, 2, 2);
-this.thisPanel.add (cb,  new J.awtjs.swing.GridBagConstraints (0, this.iRow++, 1, 1, 0.0, 0.0, 17, 0, insets, 0, 0));
+var insets =  new JS.Insets (0, 20 * level, 2, 2);
+this.thisPanel.add (cb,  new JS.GridBagConstraints (0, this.iRow++, 1, 1, 0.0, 0.0, 17, 0, insets, 0, 0));
 return cb;
 }, "~S,~S,~N,~B");
 Clazz_defineMethod (c$, "addPanelLine", 
  function (name, label, obj, units) {
-this.thisPanel.add ( new J.awtjs.swing.JLabel (label == null ? name : label),  new J.awtjs.swing.GridBagConstraints (0, this.iRow, 1, 1, 0.0, 0.0, 13, 0, this.panelInsets, 0, 0));
+this.thisPanel.add ( new JS.JLabel (label == null ? name : label),  new JS.GridBagConstraints (0, this.iRow, 1, 1, 0.0, 0.0, 13, 0, this.panelInsets, 0, 0));
 if (units == null) {
-this.thisPanel.add (obj,  new J.awtjs.swing.GridBagConstraints (1, this.iRow, 2, 1, 0.0, 0.0, 17, 0, this.panelInsets, 0, 0));
+this.thisPanel.add (obj,  new JS.GridBagConstraints (1, this.iRow, 2, 1, 0.0, 0.0, 17, 0, this.panelInsets, 0, 0));
 } else {
-this.thisPanel.add (obj,  new J.awtjs.swing.GridBagConstraints (1, this.iRow, 1, 1, 0.0, 0.0, 10, 0, this.panelInsets, 0, 0));
-this.thisPanel.add ( new J.awtjs.swing.JLabel (units),  new J.awtjs.swing.GridBagConstraints (2, this.iRow, 1, 1, 0.0, 0.0, 17, 0, this.panelInsets, 0, 0));
+this.thisPanel.add (obj,  new JS.GridBagConstraints (1, this.iRow, 1, 1, 0.0, 0.0, 10, 0, this.panelInsets, 0, 0));
+this.thisPanel.add ( new JS.JLabel (units),  new JS.GridBagConstraints (2, this.iRow, 1, 1, 0.0, 0.0, 17, 0, this.panelInsets, 0, 0));
 }this.iRow++;
-}, "~S,~S,J.awtjs.swing.JComponent,~S");
+}, "~S,~S,JS.JComponent,~S");
 Clazz_overrideMethod (c$, "addSelectOption", 
 function (name, label, info, iPt, visible) {
-var combo =  new J.awtjs.swing.JComboBox (info);
+var combo =  new JS.JComboBox (info);
 combo.setSelectedIndex (iPt);
 combo.setName (this.registryKey + "/" + name);
 if (visible) {
@@ -747,10 +743,10 @@ var key = this.optionKey + "_" + name;
 if (value == null) {
 value = this.options.get (key);
 if (value == null) this.options.put (key, (value = defaultValue));
-}var obj =  new J.awtjs.swing.JTextField (value);
+}var obj =  new JS.JTextField (value);
 obj.setName (this.registryKey + "/" + name);
 if (visible) {
-obj.setPreferredSize ( new javajs.awt.Dimension (45, 15));
+obj.setPreferredSize ( new JS.Dimension (45, 15));
 obj.addActionListener (this.manager);
 this.addPanelLine (name, label, obj, units);
 }return obj;
@@ -758,7 +754,7 @@ this.addPanelLine (name, label, obj, units);
 Clazz_overrideMethod (c$, "createTable", 
 function (data, header, widths) {
 try {
-var scrollPane =  new J.awtjs.swing.JScrollPane (this.dataTable = this.getDataTable (data, header, widths, (this.leftPanel == null ? this.defaultHeight : this.leftPanel.getHeight () - 50)));
+var scrollPane =  new JS.JScrollPane (this.dataTable = this.getDataTable (data, header, widths, (this.leftPanel == null ? this.defaultHeight : this.leftPanel.getHeight () - 50)));
 if (this.mainSplitPane == null) {
 this.getContentPane ().add (scrollPane);
 } else {
@@ -782,7 +778,7 @@ Clazz_defineMethod (c$, "getDataTable",
  function (data, columnNames, columnWidths, height) {
 this.selectedRow = -1;
 var tableModel =  new JSV.js2d.DialogTableModel (columnNames, data, !this.haveColors, this.tableCellAlignLeft);
-var table =  new J.awtjs.swing.JTable (tableModel);
+var table =  new JS.JTable (tableModel);
 var selector = table.getSelectionModel ();
 selector.addListSelectionListener (this.manager);
 this.manager.registerSelector (this.registryKey + "/ROW", selector);
@@ -831,7 +827,7 @@ function (btn, b) {
 }, "~O,~B");
 Clazz_overrideMethod (c$, "setIntLocation", 
 function (loc) {
-var d =  new javajs.awt.Dimension (0, 0);
+var d =  new JS.Dimension (0, 0);
 {
 SwingController.getScreenDimensions(d);
 }loc[0] = Math.min (d.width - 50, loc[0]);
@@ -840,7 +836,7 @@ this.setLocation (loc);
 }, "~A");
 Clazz_defineMethod (c$, "setPreferredSize", 
 function (width, height) {
-this.setPreferredSize ( new javajs.awt.Dimension (width, height));
+this.setPreferredSize ( new JS.Dimension (width, height));
 }, "~N,~N");
 Clazz_overrideMethod (c$, "setSelected", 
 function (chkbox, b) {
@@ -856,9 +852,9 @@ function (o, text) {
 }, "~O,~S");
 Clazz_overrideMethod (c$, "startLayout", 
 function () {
-this.setPreferredSize ( new javajs.awt.Dimension (600, 370));
+this.setPreferredSize ( new JS.Dimension (600, 370));
 this.getContentPane ().removeAll ();
-this.thisPanel = this.rightPanel =  new J.awtjs.swing.JPanel ( new J.awtjs.swing.FlowLayout ());
+this.thisPanel = this.rightPanel =  new JS.JPanel ( new JS.FlowLayout ());
 switch (this.type) {
 case JSV.common.Annotation.AType.Integration:
 case JSV.common.Annotation.AType.Measurements:
@@ -871,14 +867,14 @@ this.haveColors = true;
 this.haveTwoPanels = false;
 break;
 case JSV.common.Annotation.AType.Views:
-this.rightPanel =  new J.awtjs.swing.JPanel ( new J.awtjs.swing.GridBagLayout ());
+this.rightPanel =  new JS.JPanel ( new JS.GridBagLayout ());
 }
 if (this.haveTwoPanels) {
-this.thisPanel = this.leftPanel =  new J.awtjs.swing.JPanel ( new J.awtjs.swing.GridBagLayout ());
-this.leftPanel.setMinimumSize ( new javajs.awt.Dimension (200, 300));
-this.mainSplitPane =  new J.awtjs.swing.JSplitPane (1);
+this.thisPanel = this.leftPanel =  new JS.JPanel ( new JS.GridBagLayout ());
+this.leftPanel.setMinimumSize ( new JS.Dimension (200, 300));
+this.mainSplitPane =  new JS.JSplitPane (1);
 this.mainSplitPane.setLeftComponent (this.leftPanel);
-this.mainSplitPane.setRightComponent ( new J.awtjs.swing.JScrollPane (this.rightPanel));
+this.mainSplitPane.setRightComponent ( new JS.JScrollPane (this.rightPanel));
 }});
 Clazz_defineMethod (c$, "getColumnCentering", 
 function (column) {
